using System;
using setPoint.configuration;
using setPoint.semantics;
using setPoint.weaving;
using org.openrdf.sesame.sail.query;

namespace LENDLConfiguration{
	[Serializable]
	public class LENDLConfig:IConfiguration{

		private PointCutMap _pointcuts = null;
		private Advice[] _advices = null;
		private Ontology[] _ontologies = null;
		private Rule[] _rules = null;
		
		#region IConfiguration Members
		public PointCutMap pointcuts{
			get{
				if(this._pointcuts == null)
					this._pointcuts = this.createPointcuts();
				return this._pointcuts;
			}
		}
		
		public Advice[] advices{
			get{
				if(this._advices == null)
					this._advices = this.createAdvices();
				return this._advices;
			}
		}
			
		public Ontology[] ontologies{
			get{
				if(this._ontologies == null)
					this._ontologies = this.createOntologies();
				return this._ontologies;
			   }
		}
		
		public Rule[] rules{
			get{
				if(this._rules == null)
					this._rules = this.createRules();
				return this._rules;
			   }
		}
		#endregion
		
		#region private pointcut methods
		private PointCutMap createPointcuts(){
			PointCutMap pointcuts = new PointCutMap();
			///////////// BEGIN GENERATED CODE //////////
		
			pointcuts.Add("InputMessages",
				new PointCut("{message} <!semantics://programElements/objectOriented/CTS#hasAnnotation> {<!semantics://architecture#input>}"));
		
			pointcuts.Add("OutputMessages",
				new PointCut("{message} <!semantics://programElements/objectOriented/CTS#hasAnnotation> {<!semantics://architecture#output>}"));
		
			///////////// END GENERATED CODE //////////
			
			return pointcuts;
		}		
		#endregion
		
		#region private advice methods
		private Advice[] createAdvices(){
			Advice[] advices = new Advice[1];			
			AdviceBuilder builder = new AdviceBuilder();
			///////////// BEGIN GENERATED CODE //////////
		
			builder.startBuildingAdviceUsing(
				new DefaultAspectFactory(typeof(LoggingAspect)));
			
				builder.startbeforeTriggerDefinition("startLogging");
				builder.assignPointcutToCurrentTrigger(this.pointcuts["InputMessages"]);builder.assignPointcutToCurrentTrigger(this.pointcuts["OutputMessages"]);
				builder.endTriggerDefinition();
			
				builder.startafterTriggerDefinition("endLogging");
				builder.assignPointcutToCurrentTrigger(this.pointcuts["InputMessages"]);builder.assignPointcutToCurrentTrigger(this.pointcuts["OutputMessages"]);
				builder.endTriggerDefinition();
			
			advices[0] = (builder.getBuiltAdvice());
		
			///////////// END GENERATED CODE //////////						
			return advices;
		}
		#endregion
		
		#region private ontologies methods
		private Ontology[] createOntologies(){
			Ontology[] ontologies = new Ontology[1];						
					
			ontologies[0] = new Ontology("./helloWorld.owl", @"<?xml version=""1.0""?>
<rdf:RDF
    xmlns=""semantics://architecture#""
    xmlns:rdf=""http://www.w3.org/1999/02/22-rdf-syntax-ns#""
    xmlns:xsd=""http://www.w3.org/2001/XMLSchema#""
    xmlns:rdfs=""http://www.w3.org/2000/01/rdf-schema#""
    xmlns:owl=""http://www.w3.org/2002/07/owl#""
  xml:base=""semantics://architecture"">
  <owl:Ontology rdf:about=""""/>
  <owl:Class rdf:ID=""IO""/>
  <owl:Class rdf:ID=""output"">
    <rdfs:subClassOf rdf:resource=""#IO""/>
  </owl:Class>
  <owl:Class rdf:ID=""input"">
    <rdfs:subClassOf rdf:resource=""#IO""/>
  </owl:Class>
</rdf:RDF>

<!-- Created with Protege (with OWL Plugin 2.1, Build 284)  http://protege.stanford.edu -->
"); 			
					
			
			return ontologies;
		}		
		#endregion
		
		#region private inference rules methods
		private Rule[] createRules(){
			Rule[] rules = new Rule[0];						
								
			return rules;
		}		
		#endregion
	}
}
